Index: pgadmin/include/schema/pgTable.h
===================================================================
--- pgadmin/include/schema/pgTable.h	(revision 8061)
+++ pgadmin/include/schema/pgTable.h	(working copy)
@@ -103,8 +103,8 @@
     void iSetAppendOnly(const wxString& s) { appendOnly = s; }
     wxString GetCompressLevel() { return compressLevel; }
     void iSetCompressLevel(const wxString& s) { compressLevel = s; }
-    wxString GetIsColumnStore() { return columnstore; }
-    void iSetIsColumnStore(const wxString& s) { columnstore = s; }
+    wxString GetOrientation() { return orientation; }
+    void iSetOrientation(const wxString& s) { orientation = s; }
     wxString GetCompressType() { return compresstype; }
     void iSetCompressType(const wxString& s) { compresstype = s; };
     wxString GetBlocksize() { return blocksize; }
@@ -209,7 +209,7 @@
              autovacuum_freeze_max_age, autovacuum_freeze_table_age;
     wxString appendOnly;
     wxString compressLevel;
-    wxString columnstore;
+    wxString orientation;  // "row" or "column"
     wxString compresstype;
     wxString blocksize;
     wxString checksum;
Index: pgadmin/schema/gpPartition.cpp
===================================================================
--- pgadmin/schema/gpPartition.cpp	(revision 8061)
+++ pgadmin/schema/gpPartition.cpp	(working copy)
@@ -119,7 +119,7 @@
 	query += wxT(", gpd.localoid, gpd.attrnums \n");
 	query += wxT(", substring(array_to_string(reloptions, ',') from 'appendonly=([a-z]*)') AS appendonly \n");
 	query += wxT(", substring(array_to_string(reloptions, ',') from 'compresslevel=([0-9]*)') AS compresslevel \n");
-    query += wxT(", substring(array_to_string(reloptions, ',') from 'columnstore=([a-z]*)') AS columnstore \n");
+    query += wxT(", substring(array_to_string(reloptions, ',') from 'orientation=([a-z]*)') AS orientation \n");
     query += wxT(", substring(array_to_string(reloptions, ',') from 'compresstype=([a-z0-9]*)') AS compresstype \n");
     query += wxT(", substring(array_to_string(reloptions, ',') from 'blocksize=([0-9]*)') AS blocksize \n");
     query += wxT(", substring(array_to_string(reloptions, ',') from 'checksum=([a-z]*)') AS checksum \n");
@@ -185,7 +185,7 @@
 				table->iSetDistributionIsRandom();
 			table->iSetAppendOnly(tables->GetVal(wxT("appendonly")));
 			table->iSetCompressLevel(tables->GetVal(wxT("compresslevel")));
-            table->iSetIsColumnStore(tables->GetVal(wxT("columnstore")));
+            table->iSetOrientation(tables->GetVal(wxT("orientation")));
             table->iSetCompressType(tables->GetVal(wxT("compresstype")));
             table->iSetBlocksize(tables->GetVal(wxT("blocksize")));
             table->iSetChecksum(tables->GetVal(wxT("checksum")));
Index: pgadmin/schema/pgTable.cpp
===================================================================
--- pgadmin/schema/pgTable.cpp	(revision 8061)
+++ pgadmin/schema/pgTable.cpp	(working copy)
@@ -348,8 +348,8 @@
                 sql += wxT("APPENDONLY=") + GetAppendOnly() + wxT(", ");
             if (GetCompressLevel().Length() > 0)
                 sql += wxT("COMPRESSLEVEL=") + GetCompressLevel() + wxT(", ");
-            if (GetIsColumnStore().Length() > 0)
-                sql += wxT("COLUMNSTORE=") + GetIsColumnStore() + wxT(", ");
+            if (GetOrientation().Length() > 0)
+                sql += wxT("ORIENTATION=") + GetOrientation() + wxT(", ");
             if (GetCompressType().Length() > 0)
                 sql += wxT("COMPRESSTYPE=") + GetCompressType() + wxT(", ");
             if (GetBlocksize().Length() > 0)
@@ -817,6 +817,12 @@
         CreateListColumns(properties);
 
         properties->AppendItem(_("Name"), GetName());
+        if (GetConnection() != 0 && GetConnection()->GetIsGreenplum())
+        {
+            gpPartition * p = dynamic_cast<gpPartition *>(this);
+            if (p != 0)
+                properties->AppendItem(_("Partition Name"), p->GetPartitionName());   
+        }
         properties->AppendItem(_("OID"), GetOid());
         properties->AppendItem(_("Owner"), GetOwner());
         if (GetConnection()->BackendMinimumVersion(8, 0))
@@ -1221,7 +1227,7 @@
             query += wxT(", gpd.localoid, gpd.attrnums \n");
             query += wxT(", substring(array_to_string(rel.reloptions, ',') from 'appendonly=([a-z]*)') AS appendonly \n");
             query += wxT(", substring(array_to_string(rel.reloptions, ',') from 'compresslevel=([0-9]*)') AS compresslevel \n");
-            query += wxT(", substring(array_to_string(rel.reloptions, ',') from 'columnstore=([a-z]*)') AS columnstore \n");
+            query += wxT(", substring(array_to_string(rel.reloptions, ',') from 'orientation=([a-z]*)') AS orientation \n");
             query += wxT(", substring(array_to_string(rel.reloptions, ',') from 'compresstype=([a-z0-9]*)') AS compresstype \n");
             query += wxT(", substring(array_to_string(reloptions, ',') from 'blocksize=([0-9]*)') AS blocksize \n");
             query += wxT(", substring(array_to_string(reloptions, ',') from 'checksum=([a-z]*)') AS checksum \n");
@@ -1391,7 +1397,7 @@
                     table->iSetDistributionIsRandom();
                 table->iSetAppendOnly(tables->GetVal(wxT("appendonly")));
                 table->iSetCompressLevel(tables->GetVal(wxT("compresslevel")));
-                table->iSetIsColumnStore(tables->GetVal(wxT("columnstore")));
+                table->iSetOrientation(tables->GetVal(wxT("orientation")));
                 table->iSetCompressType(tables->GetVal(wxT("compresstype")));
                 table->iSetBlocksize(tables->GetVal(wxT("blocksize")));
                 table->iSetChecksum(tables->GetVal(wxT("checksum")));
